==> camunda-engine-spring-7.6.0-test-sources.jar: org/camunda/bpm/engine/spring/test/ExampleConfiguration.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.spring.test;

import org.camunda.bpm.engine.ProcessEngineConfiguration;
import org.camunda.bpm.engine.impl.cfg.ProcessEngineConfigurationImpl;
import org.camunda.bpm.engine.impl.cfg.StandaloneInMemProcessEngineConfiguration;
import org.camunda.bpm.engine.spring.ProcessEngineFactoryBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @author Thorben Lindhauer
 *
 */
@Configuration
public class ExampleConfiguration {

  @Bean
  public ProcessEngineConfiguration processEngineConfiguration() {
    return new StandaloneInMemProcessEngineConfiguration().setJobExecutorDeploymentAware(true);
  }

  @Bean
  public ProcessEngineFactoryBean processEngine() throws Exception {
    ProcessEngineFactoryBean engineFactoryBean = new ProcessEngineFactoryBean();
    engineFactoryBean.setProcessEngineConfiguration((ProcessEngineConfigurationImpl) processEngineConfiguration());

    return engineFactoryBean;
  }
}

==> camunda-engine-spring-7.24.0-test-sources.jar: org/camunda/bpm/engine/spring/test/ExampleConfiguration.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.spring.test;

import org.camunda.bpm.engine.ProcessEngineConfiguration;
import org.camunda.bpm.engine.impl.cfg.ProcessEngineConfigurationImpl;
import org.camunda.bpm.engine.impl.cfg.StandaloneInMemProcessEngineConfiguration;
import org.camunda.bpm.engine.spring.ProcessEngineFactoryBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @author Thorben Lindhauer
 *
 */
@Configuration
public class ExampleConfiguration {

  @Bean
  public ProcessEngineConfiguration processEngineConfiguration() {
    return new StandaloneInMemProcessEngineConfiguration()
        .setJobExecutorDeploymentAware(true)
        .setDatabaseSchemaUpdate(ProcessEngineConfiguration.DB_SCHEMA_UPDATE_TRUE);
  }

  @Bean
  public ProcessEngineFactoryBean processEngine() throws Exception {
    ProcessEngineFactoryBean engineFactoryBean = new ProcessEngineFactoryBean();
    engineFactoryBean.setProcessEngineConfiguration((ProcessEngineConfigurationImpl) processEngineConfiguration());

    return engineFactoryBean;
  }
}
